import { Client, Scope, Span } from '@sentry/types';
type TraceData = {
    'sentry-trace'?: string;
    baggage?: string;
};
/**
 * Extracts trace propagation data from the current span or from the client's scope (via transaction or propagation
 * context) and serializes it to `sentry-trace` and `baggage` values to strings. These values can be used to propagate
 * a trace via our tracing Http headers or Html `<meta>` tags.
 *
 * This function also applies some validation to the generated sentry-trace and baggage values to ensure that
 * only valid strings are returned.
 *
 * @param span a span to take the trace data from. By default, the currently active span is used.
 * @param scope the scope to take trace data from By default, the active current scope is used.
 * @param client the SDK's client to take trace data from. By default, the current client is used.
 *
 * @returns an object with the tracing data values. The object keys are the name of the tracing key to be used as header
 * or meta tag name.
 */
export declare function getTraceData(span?: Span, scope?: Scope, client?: Client): TraceData;
/**
 * Tests string against baggage spec as defined in:
 *
 * - W3C Baggage grammar: https://www.w3.org/TR/baggage/#definition
 * - RFC7230 token definition: https://datatracker.ietf.org/doc/html/rfc7230#section-3.2.6
 *
 * exported for testing
 */
export declare function isValidBaggageString(baggage?: string): boolean;
export {};
//# sourceMappingURL=traceData.d.ts.map
